==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/General/trackchange/translations/trackchange_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Track Change Plugin Settings</source>
        <translation>Setelan Plugin Perubahan Track</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <location filename="../settingsdialog.ui" line="42"/>
        <location filename="../settingsdialog.ui" line="52"/>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Command to run when Qmmp starts new track</source>
        <translation>Perintah untuk menjalankan ketika Qmmp memulai track baru</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Command to run toward to end of a track</source>
        <translation>Perintah untuk menjalankan ke arah akhir dari sebuah track</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Command to run when Qmmp reaches the end of the playlist</source>
        <translation>Perintah untuk menjalankan ketika Qmmp mencapai akhir dari sebuah daftarmain</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Command to run when title changes (i.e. network streams title)</source>
        <translation>Perintah untuk menjalankan ketika perubahan judul (yaitu judul stream jaringan)</translation>
    </message>
</context>
<context>
    <name>TrackChangeFactory</name>
    <message>
        <location filename="../trackchangefactory.cpp" line="30"/>
        <source>Track Change Plugin</source>
        <translation>Plugin Perubahan Track</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="50"/>
        <source>About Track Change Plugin</source>
        <translation>Tentang Plugin Perubahan Track</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="51"/>
        <source>Qmmp Track Change Plugin</source>
        <translation>Plugin Perubahan Track Qmmp</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="52"/>
        <source>This plugin executes external command when current track is changed</source>
        <translation>Plugin ini mengeksekusi perintah eksternal ketika track saat ini telah diubah</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/General/trackchange/translations/trackchange_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Track Change Plugin Settings</source>
        <translation>Setelan Plugin Perubahan Track</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <location filename="../settingsdialog.ui" line="56"/>
        <location filename="../settingsdialog.ui" line="73"/>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Command to run when Qmmp starts new track</source>
        <translation>Perintah untuk menjalankan ketika Qmmp memulai track baru</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Command to run toward to end of a track</source>
        <translation>Perintah untuk menjalankan ke arah akhir dari sebuah track</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Command to run when Qmmp reaches the end of the playlist</source>
        <translation>Perintah untuk menjalankan ketika Qmmp mencapai akhir dari sebuah daftarmain</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Command to run when title changes (i.e. network streams title)</source>
        <translation>Perintah untuk menjalankan ketika perubahan judul (yaitu judul stream jaringan)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Command to run on application startup:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>Command to run on application exit:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrackChangeFactory</name>
    <message>
        <location filename="../trackchangefactory.cpp" line="30"/>
        <source>Track Change Plugin</source>
        <translation>Plugin Perubahan Track</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="50"/>
        <source>About Track Change Plugin</source>
        <translation>Tentang Plugin Perubahan Track</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="51"/>
        <source>Qmmp Track Change Plugin</source>
        <translation>Plugin Perubahan Track Qmmp</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="52"/>
        <source>This plugin executes external command when current track is changed</source>
        <translation>Plugin ini mengeksekusi perintah eksternal ketika track saat ini telah diubah</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
